version

package
v0.1.1 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: May 13, 2026 License: MIT Imports: 0 Imported by: 0

Documentation

Overview

Package version exposes the build version of the xpc binary.

Version is intended to be overridden at build time via -ldflags "-X github.com/nficano/xpc/internal/version.Version=<value>".

Index

Constants

This section is empty.

Variables

var Codename = ""

Codename is the human-friendly release name (e.g. "loony-lionfish") set by the release workflow via -ldflags. Empty for dev builds.

var Version = "0.0.0-dev"

Version is the human-readable version string. Default is suitable for development builds; release builds override it via -ldflags.

Functions

func String

func String() string

String returns the version string, with the codename appended in parens when set by a release build.

Types

This section is empty.

Jump to